Input

Enum Input 

pub enum Input {
    Unspecified,
    SourceGraphic,
    SourceAlpha,
    BackgroundImage,
    BackgroundAlpha,
    FillPaint,
    StrokePaint,
    FilterOutput(CustomIdent),
}
An enumeration of possible inputs for a filter primitive.

Variants



Unspecified



SourceGraphic



SourceAlpha



BackgroundImage



BackgroundAlpha



FillPaint



StrokePaint



FilterOutput(CustomIdent)

Implementations

Source

impl Input

pub fn get_requirements(&self) -> InputRequirements

Returns what kind of pre-computed image is needed as the input for a filter primitive.

In a filter value list, some primitives may reference a particular kind of source content with the in attribute. The code flow becomes easier by being able to render this source content before processing the filter value list.