FilterPlan

Struct FilterPlan 

pub struct FilterPlan {
    session: Session,
    pub viewport: Viewport,
    background_image: Option<SharedImageSurface>,
    stroke_paint_image: Option<SharedImageSurface>,
    fill_paint_image: Option<SharedImageSurface>,
}
Parameters using while rendering a whole filter property.

The filter property may contain a single primitive, like filter="blur(2px)", or a list of filter specs like filter="blur(2px) url(#filter_id) drop_shadow(5 5)". Each of those specs may produce more than one primitive; for example, the url(#filter_id) there may refer to a <filter> element that has several primitives inside it. Also, the drop_shadow() function will expand to the few primitives used to implement a drop shadow.

Each filter spec will be rendered within a FilterContext, so that the context can maintain the list of named outputs within a <filter> element, so that primitives can feed their inputs and outputs into each other.

While rendering all those FilterContexts, there are some immutable parameters. This FilterPlan struct contains those parameters. If at least one of the filter primitives involved has an in attribute with a value of BackgroundImage/StrokePaint/FillPaint, then this struct will also contain a pre-rendered image surface with the appropriate content. Pre-computing those required “filler” images makes the code simple, since then the filters do not need to call out again to the rendering code.

Fields

session: Sessionviewport: Viewport

Current viewport at the time the filter is invoked.

background_image: Option<SharedImageSurface>

Surface corresponding to the background image snapshot, for in="BackgroundImage".

stroke_paint_image: Option<SharedImageSurface>

Surface filled with the current stroke paint, for in="StrokePaint".

Filter Effects 1: https://www.w3.org/TR/filter-effects/#attr-valuedef-in-strokepaint

fill_paint_image: Option<SharedImageSurface>

Surface filled with the current fill paint, for in="FillPaint".

Filter Effects 1: https://www.w3.org/TR/filter-effects/#attr-valuedef-in-fillpaint

Implementations

Source

impl FilterPlan

pub fn new( session: &Session, viewport: Viewport, requirements: InputRequirements, background_image: Option<SharedImageSurface>, stroke_paint_image: Option<SharedImageSurface>, fill_paint_image: Option<SharedImageSurface>, ) -> Result<FilterPlan, Box<InternalRenderingError>>