pub struct FilterSpec {
pub name: String,
pub user_space_filter: UserSpaceFilter,
pub primitives: Vec<UserSpacePrimitive>,
}Expand description
Parameters to apply a list of SVG filter primitives onto a surface.
This is almost everything needed to take a surface and apply a list of SVG filter primitives to it.
Fields
name: StringHuman-readable identifier for the filter, for logging/debugging purposes.
user_space_filter: UserSpaceFilterCoordinates and bounds.
primitives: Vec<UserSpacePrimitive>List of filter primitives to apply to the surface, in order.