pub struct InputRequirements {
pub needs_source_alpha: bool,
pub needs_background_image: bool,
pub needs_background_alpha: bool,
pub needs_stroke_paint_image: bool,
pub needs_fill_paint_image: bool,
}Expand description
Which surfaces need to be provided as inputs for a FilterPlan.
The various filters in a filter property may require different source images that
the calling DrawingCtx is able to compute. For example, if a primitive inside a
<filter> element has in="FillPaint", then the calling DrawingCtx must supply a
surface filled as per the fill property of the element being filtered.
This struct holds the requirements for which such surfaces are needed. The caller is
expected to construct it from an array of FilterSpec, and then to create the
corresponding Input to create a FilterPlan.
See the in
attribute
from the Filter Effects Module Level 1.
Fields
needs_source_alpha: boolAt least one input is in=SourceAlpha.
needs_background_image: boolAt least one input is in=BackgroundImage.
needs_background_alpha: boolAt least one input is in=BackgroundAlpha.
needs_stroke_paint_image: boolAt least one input is in=StrokePaint.
needs_fill_paint_image: boolAt least one input is in=FillPaint.
Implementations
Sourceimpl InputRequirements
impl InputRequirements
Sourcepub fn new_from_filter_specs(specs: &[FilterSpec]) -> InputRequirements
pub fn new_from_filter_specs(specs: &[FilterSpec]) -> InputRequirements
Scans a list of FilterSpec to find out which contents need to be pre-rendered to process the filters.
fn fold(self, r: InputRequirements) -> InputRequirements