pub struct InputRequirements {
pub needs_source_alpha: bool,
pub needs_background_image: bool,
pub needs_background_alpha: bool,
pub needs_stroke_paint_image: bool,
pub needs_fill_paint_image: bool,
}Expand description
Which surfaces need to be provided as inputs for a FilterPlan.
The various filters in a filter property may require different source images that
the calling DrawingCtx is able to compute. For example, if a primitive inside a
<filter> element has in="FillPaint", then the calling DrawingCtx must supply a
surface filled as per the fill property of the element being filtered.
This struct holds the requirements for which such surfaces are needed. The caller is
expected to construct it from an array of FilterSpec, and then to create the
corresponding Input to create a FilterPlan.
Fields
needs_source_alpha: boolneeds_background_image: boolneeds_background_alpha: boolneeds_stroke_paint_image: boolneeds_fill_paint_image: boolImplementations
Sourceimpl InputRequirements
impl InputRequirements
pub fn new_from_filter_specs(specs: &[FilterSpec]) -> InputRequirements
fn fold(self, r: InputRequirements) -> InputRequirements